<?php
/**
 * A class for user registration
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface UserRegister extends AddableCriteria {
	/**
	 * Encrypt given request key or throws an exception if key was not found in
	 * request.
	 *
	 * @param	$requestKey		Key in request class
	 * @return	void
	 */
	function encryptPassword ($requestKey);

	/**
	 * Perform things like informing assigned affilates about new registration
	 * before registration
	 *
	 * @return	void
	 */
	function doPreRegistration ();

	/**
	 * Registers the new user account by insterting the request data into the
	 * database and paying some start credits or throw exceptions if this fails
	 *
	 * @return	void
	 */
	function registerNewUser ();

	/**
	 * Perform things like notifying partner websites after registration is done
	 *
	 * @return	void
	 */
	function doPostRegistration ();

	/**
	 * Do the action which is required after all registration steps are done.
	 * This can be a simple redirect to another webpage or displaying a message
	 * to the user. Or this can be a login step into the newly created account.
	 *
	 * @return	void
	 */
	function doPostAction ();
}

// [EOF]
?>
